@@ -383,10 +383,12 @@ test_that("residual",{
   
   expect_is(residuals(fit0), class="numeric")
   expect_is(residuals(fit1, "dfbetas"), class="matrix")
-  expect_s3_class(cox.zph(fit0), "cox.zph")
+  expect_s3_class(cox.zph(fit0, transform="rank"), "cox.zph")
+  expect_error(cox.zph(fit1),"This model did not use coxph within g-estimation")
 })
 
 
+
 test_that("extract_z",{
   expect_warning(
     rpsftm(Surv(progyrs, prog)~rand(imm,1-xoyrs/progyrs),immdef[1:2,], censor_time = censyrs),
